@@ -1,5 +1,9 @@
 // -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 // vi: set et ts=4 sw=2 sts=2:
+
+// SPDX-FileCopyrightText: Copyright © DUNE Project contributors, see file AUTHORS.md
+// SPDX-License-Identifier: LicenseRef-GPL-2.0-only-with-DUNE-exception OR LGPL-3.0-or-later
+
 #include <config.h>
 
 #include <iostream>
@@ -158,7 +162,7 @@ struct DerivativeRangeTerminationTest
       std::cout << "Type of " << recursionLevel << "-th derivative is " << Dune::className<DR>() << std::endl;
       typedef typename Dune::Functions::DerivativeTraits<D, DR>::DerivativeRange DDR;
       int upperBound = TerminationTest<DDR, recursionLevel+1>::level();
-      if (Dune::is_same<DR, DDR>::value)
+      if (std::is_same_v<DR, DDR>)
         return recursionLevel;
       else
         return upperBound;
@@ -172,7 +176,7 @@ struct DerivativeRangeTerminationTest
     {
       std::cout << "Type of " << maxRecursionLevel << "-th derivative is " << Dune::className<DR>() << std::endl;
       typedef typename Dune::Functions::DerivativeTraits<D, DR>::DerivativeRange DDR;
-      if (Dune::is_same<DR, DDR>::value)
+      if (std::is_same_v<DR, DDR>)
         return maxRecursionLevel;
       else
         return maxRecursionLevel+1;
