@@ -1,5 +1,9 @@
 // -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 // vi: set et ts=4 sw=2 sts=2:
+
+// SPDX-FileCopyrightText: Copyright © DUNE Project contributors, see file AUTHORS.md
+// SPDX-License-Identifier: LicenseRef-GPL-2.0-only-with-DUNE-exception OR LGPL-3.0-or-later
+
 #include <config.h>
 
 #include <iostream>
@@ -15,8 +19,6 @@
 #include <dune/grid/uggrid.hh>
 #include <dune/grid/io/file/gmshreader.hh>
 
-#include <dune/localfunctions/test/test-localfe.hh>
-
 #include <dune/functions/functionspacebases/interpolate.hh>
 #include <dune/functions/functionspacebases/lagrangebasis.hh>
 #include <dune/functions/functionspacebases/lagrangedgbasis.hh>
@@ -30,13 +32,11 @@ using namespace Dune::Functions;
 /** \param disableInterpolate Not all bases can correctly represent the linear function
  *      that we use to test whether integrating over a given function gives the correct
  *      value (e.g. basis without dofs on the boundary).  Therefore we allow to disable this test.
- *  \param disabledLocalTests Allows to disable certain local tests (see dune-localfunctions/dune/localfunctions/test/test-localfe.hh)
  */
 template <typename Basis>
 void testScalarBasisConst(const Basis& feBasis,
                      bool isPartitionOfUnity,
-                     bool disableInterpolate = false,
-                     char disabledLocalTests = DisableNone)
+                     bool disableInterpolate = false)
 {
   static const int dim = Basis::GridView::dimension;
 
@@ -194,11 +194,10 @@ void testScalarBasisConst(const Basis& feBasis,
 template <typename Basis, typename GV>
 void testScalarBasis(Basis& feBasis, GV gv,
                      bool isPartitionOfUnity,
-                     bool disableInterpolate = false,
-                     char disabledLocalTests = DisableNone)
+                     bool disableInterpolate = false)
 {
   feBasis.update(gv);
-  testScalarBasisConst(feBasis, isPartitionOfUnity, disableInterpolate, disabledLocalTests);
+  testScalarBasisConst(feBasis, isPartitionOfUnity, disableInterpolate);
 }
 
 template <int dim>
@@ -261,8 +260,8 @@ void testOnStructuredGrid()
     BSplineBasis<GridView> bSplineBasis(gridView, knotVector, order);
     testScalarBasisConst(bSplineBasis,
                     true,
-                    true,      // Don't interpolate a given function and try to integrate over it
-                    DisableLocalInterpolation);
+                    true);      // Don't interpolate a given function and try to integrate over it
+
   }
 
   // Testing B-spline basis with non-open knot vectors
@@ -274,17 +273,14 @@ void testOnStructuredGrid()
     BSplineBasis<GridView> bSplineBasis(gridView, knotVector, order, false);
     testScalarBasisConst(bSplineBasis,
                     order==0,   // only zero-order B-splines for a partition of unity
-                    true,      // Don't interpolate a given function and try to integrate over it
-                    DisableLocalInterpolation);
+                    true);      // Don't interpolate a given function and try to integrate over it
+
   }
 }
 
 template <int dim>
 void testOnHybridGrid()
 {
-#if ! HAVE_DUNE_UGGRID
-  std::cout << "   ---- Skipping test on hybrid " << dim << "d grid -- UGGrid is not installed ----" << std::endl;
-#else
   std::cout << "   +++++++++++  Testing on hybrid " << dim << "d grid  ++++++++++++" << std::endl;
 
   // Generate grid for testing
@@ -332,7 +328,6 @@ void testOnHybridGrid()
   // \todo Enable these tests once pyramid element of order three is implemented
 //  LagrangeDGBasis<GridView, 3> lagrangeDG3Basis(gridView);
 //  testScalarBasisConst(lagrangeDG3Basis, true, disableInterpolate);
-#endif
 }
 
 
