@@ -1,11 +1,17 @@
 // -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 // vi: set et ts=4 sw=2 sts=2:
+
+// SPDX-FileCopyrightText: Copyright © DUNE Project contributors, see file AUTHORS.md
+// SPDX-License-Identifier: LicenseRef-GPL-2.0-only-with-DUNE-exception OR LGPL-3.0-or-later
+
 #include <config.h>
 
 #include <iostream>
+#include <tuple>
 
 #include <dune/common/exceptions.hh>
 #include <dune/common/parallel/mpihelper.hh>
+#include <dune/common/hybridutilities.hh>
 
 #include <dune/grid/yaspgrid.hh>
 
@@ -43,23 +49,31 @@ double infinityDiff(const bool& x, const bool& y)
 template<class R, class B, class C>
 bool checkInterpolationConsistency(B&& basis, C&& x)
 {
-  using Coeff = typename std::decay<C>::type;
+  using Coeff = std::decay_t<C>;
   using Range = R;
 
+  bool passed = true;
+
   // generate a discrete function
   auto f = Dune::Functions::makeDiscreteGlobalBasisFunction<Range>(basis, x);
 
-  Coeff y;
-  interpolate(basis, y, f);
-  for (typename std::decay_t<C>::size_type i=0; i<x.size(); ++i)
-  {
-    if (infinityDiff(x[i],y[i]) > 1e-10)
+  // By wrapping into a lambda, we force interpolate to use the global evaluation of f
+  auto fGlobal = [&](auto x){ return f(x); };
+
+  Dune::Hybrid::forEach(std::tie(f, fGlobal), [&](auto&& ff) {
+    Coeff y;
+    interpolate(basis, y, ff);
+    for (typename std::decay_t<C>::size_type i=0; i<x.size(); ++i)
     {
-      std::cout << "Interpolation of DiscreteGlobalBasisFunction differs from original coefficient vector" << std::endl;
-      return false;
+      if (infinityDiff(x[i],y[i]) > 1e-10)
+      {
+        std::cout << "Interpolation of DiscreteGlobalBasisFunction differs from original coefficient vector" << std::endl;
+        passed = false;
+      }
     }
-  }
-  return true;
+  });
+
+  return passed;
 }
 
 
@@ -75,28 +89,10 @@ int main (int argc, char* argv[]) try
   std::array<int,dim> elements = {{10, 10}};
   GridType grid(l,elements);
 
-  using namespace Functions::BasisBuilder;
+  using namespace Functions::BasisFactory;
 
   const auto& gridView = grid.leafGridView();
 
-  // scalar Lagrange basis with vector valued coefficients
-  {
-    using Range = FieldVector<double,5>;
-    auto f = [](const auto& x){
-      Range y;
-      for (typename Range::size_type i=0; i<y.size(); ++i)
-        y[i] = x[0]+i;
-      return y;
-    };
-
-    std::vector<Range> x;
-    auto feBasis = makeBasis(gridView,lagrange<1>());
-    interpolate(feBasis, x, f);
-    auto passedThisTest = checkInterpolationConsistency<Range>(feBasis, x);
-    std::cout << "checkInterpolationConsistency for scalar Lagrange basis with vector-valued coefficients " << (passedThisTest? " " : " NOT  ") << "successful." << std::endl;
-    passed = passed and passedThisTest;
-  }
-
   // scalar Lagrange Basis
   {
     auto feBasis = makeBasis(gridView,lagrange<1>());
