@@ -1,5 +1,9 @@
 // -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 // vi: set et ts=4 sw=2 sts=2:
+
+// SPDX-FileCopyrightText: Copyright © DUNE Project contributors, see file AUTHORS.md
+// SPDX-License-Identifier: LicenseRef-GPL-2.0-only-with-DUNE-exception OR LGPL-3.0-or-later
+
 #include <config.h>
 
 #include <vector>
@@ -62,7 +66,7 @@ int main (int argc, char *argv[])
 
   // Interpolate a vector-valued function using a vector-valued basis
   // { taylorhood_basis_begin }
-  using namespace Functions::BasisBuilder;
+  using namespace Functions::BasisFactory;
 
   auto taylorHoodBasis = makeBasis(
     gridView,
