@@ -1,5 +1,9 @@
 // -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 // vi: set et ts=4 sw=2 sts=2:
+
+// SPDX-FileCopyrightText: Copyright © DUNE Project contributors, see file AUTHORS.md
+// SPDX-License-Identifier: LicenseRef-GPL-2.0-only-with-DUNE-exception OR LGPL-3.0-or-later
+
 #include <config.h>
 
 #include <vector>
@@ -7,6 +11,7 @@
 
 #include <dune/common/bitsetvector.hh>
 #include <dune/common/indices.hh>
+#include <dune/common/rangeutilities.hh>
 
 #include <dune/geometry/quadraturerules.hh>
 
@@ -41,7 +46,7 @@ template <class LocalView, class MatrixType>
 void getLocalMatrix(const LocalView& localView,
                     MatrixType& elementMatrix)
 {
-  // Get the grid element from the local FE basis view (use test space)
+  // Get the grid element from the local FE basis view
   typedef typename LocalView::Element Element;
   const Element& element = localView.element();
 
@@ -134,7 +139,7 @@ void getLocalMatrix(const LocalView& localView,
         size_t pressureIndex = localView.tree().child(_1).localIndex(j);
 
         // Pre-compute matrix contribution
-        double tmp = - (fluxDivergence[i] * pressureValues[j]) * quadPoint.weight() * integrationElement;
+        double tmp = (fluxDivergence[i] * pressureValues[j]) * quadPoint.weight() * integrationElement;
 
         elementMatrix[fluxIndex][pressureIndex] += tmp;
         elementMatrix[pressureIndex][fluxIndex] += tmp;
@@ -386,9 +391,9 @@ int main (int argc, char *argv[])
   //   Stiffness matrix and right hand side vector
   /////////////////////////////////////////////////////////
 
-  using MatrixType = Matrix<BCRSMatrix<FieldMatrix<double,1,1> > >;
-  using VectorType = BlockVector<BlockVector<FieldVector<double,1> > >;
-  using BitVectorType = BlockVector<BlockVector<FieldVector<char,1> > >;
+  using MatrixType = Matrix<BCRSMatrix<double> >;
+  using VectorType = BlockVector<BlockVector<double> >;
+  using BitVectorType = BlockVector<BlockVector<char> >;
 
   using Functions::istlVectorBackend;
 
@@ -403,7 +408,7 @@ int main (int argc, char *argv[])
 
   assembleMixedPoissonMatrix(basis, stiffnessMatrix);
 
-  auto rightHandSide = [] (const Domain& x) { return 10; };
+  auto rightHandSide = [] (const Domain& x) { return 2; };
 
   assembleMixedPoissonRhs(basis, rhs, rightHandSide);
 
@@ -416,7 +421,7 @@ int main (int argc, char *argv[])
   auto normal = Dune::Functions::FaceNormalGridFunction(gridView);
   auto fluxDirichletValues = Dune::Functions::makeComposedGridFunction(
     [pi = std::acos(-1.0)](const auto& x, const auto& normal) {
-      return (-0.05 * (1. - x[0]) * std::sin(2.*pi*x[0])) * normal;
+      return std::sin(2.*pi*x[0]) * normal;
     },
     coordinate,
     normal);
@@ -443,14 +448,11 @@ int main (int argc, char *argv[])
   {
     if (isDirichlet[0][i])
     {
-      // Lower right matrix block
-      auto cIt    = stiffnessMatrix[0][0][i].begin();
-      auto cEndIt = stiffnessMatrix[0][0][i].end();
-      // loop over nonzero matrix entries in current row
-      for (; cIt!=cEndIt; ++cIt)
-        *cIt = (i==cIt.index()) ? 1. : 0.;
+      // Upper left matrix block
+      for (auto&& [entry, idx] : sparseRange(stiffnessMatrix[0][0][i]))
+        entry = (i==idx) ? 1.0 : 0.0;
 
-      // Lower left matrix block
+      // Upper right matrix block
       for (auto&& entry: stiffnessMatrix[0][1][i])
         entry = 0.0;
     }
